@@ -1,4 +1,5 @@
-dsaggwidth <-
+#' @export
+`dsaggwidth` <-
 function(x){
 # Aggregated width of all focal elements of a BPA x (area between Bel(x) and Pl(x))
 #=========================================================================
