@@ -1,4 +1,5 @@
-dsbel <-
+#' @export
+`dsbel` <-
 function(x){
 # Belief function
 #=========================================================================   
