@@ -1,4 +1,5 @@
-dsecdf <-
+#' @export
+`dsecdf` <-
 function(x){
 # Returns empirical CDF of a sample x or set of empirical CDFs of an interval sample x
 #=========================================================================   
