@@ -1,4 +1,5 @@
-dsecdffit <-
+#' @export
+`dsecdffit` <-
 function(x){
 # Generates BPA from empirical CDF bounds on data set x (points, intervals)
 #=========================================================================
