@@ -1,4 +1,5 @@
-dslapconf <-
+#' @export
+`dslapconf` <-
 function(x,lims=c(-Inf,Inf)){
 # Generates BPA from Kolmogorov-Smirnov bounds on data set x (points, intervals)
 #=========================================================================
