@@ -1,4 +1,5 @@
-dsopt <-
+#' @export
+`dsopt` <-
 function(fr,xlo,xhi,mass,...,samples=NULL){
 # Optimization routine for complex nonlinear functions using Matlabs Optimization Toolbox
 #=========================================================================   
