@@ -1,4 +1,5 @@
-dspl <-
+#' @export
+`dspl` <-
 function(x){
 # Plausibility function
 #=========================================================================   
