@@ -1,4 +1,5 @@
-dsqqplot <-
+#' @export
+`dsqqplot` <-
 function(ds,sample,points=FALSE){
 # Plots quantile-quantile plots for a BPA ds and a set of points sample.
 #=========================================================================
