@@ -1,4 +1,5 @@
-dsred <-
+#' @export
+`dsred` <-
 function(y,thres=0.001){
 # Reduces the size of a Dempster-Shafer structure
 #=========================================================================   
