@@ -1,4 +1,5 @@
-dssaveintersect <-
+#' @export
+`dssaveintersect` <-
 function(...,method='averaging'){
 # Save intersection of BPAs "..." using method "averaging" or "envelope" in case of conflict.
 #=========================================================================
