@@ -1,4 +1,5 @@
-dswavg <-
+#' @export
+`dswavg` <-
 function(...,w=NULL){
 # Weighted average of BPAs "..." with optional weights w
 #=========================================================================
